@@ -55,7 +55,7 @@ class IOSSpeechDriver(BaseDriver):
 	def __init__(self, proxy, **kw):
 		super().__init__(proxy)
 		self._tts = AVSpeechSynthesizer.alloc().init()
-		# self._tts.delegate = self
+		self._tts.delegate = self
 		self.volume = 1
 		self._completed = True
 		self.rate = 180
@@ -140,10 +140,10 @@ class IOSSpeechDriver(BaseDriver):
 		locale = language_by_lang(sentence.lang)
 		voice = AVSpeechSynthesisVoice.voiceWithLanguage_(objc_str(locale))
 		utterance.voice = voice
-		utterance.rate = self.rate
+		# utterance.rate = self.rate
 
 	def speak_sentence(self, sentence):
-		utterance = AVSpeechUtterance.alloc().init(sentence.text)
+		utterance = AVSpeechUtterance.speechUtteranceWithString_(objc_str(sentence.text))
 		self.set_utterances_by_sentence(utterance, sentence)
 		self._tts.speakUtterance_(utterance)
 		print('speak_sentence() finished')
@@ -180,7 +180,6 @@ class IOSSpeechDriver(BaseDriver):
 		url = NSURL.fileURLWithPath_(filename)
 		self._tts.startSpeakingString_toURL_(text, url)
 
-	"""
 	@protocol('AVSpeechSynthesizerDelegate')
 	def speechSynthesizer_didStart_(self, *args):
 		print('didStart_(): args=', args)
@@ -214,5 +213,4 @@ class IOSSpeechDriver(BaseDriver):
 	@protocol('AVSpeechSynthesizerDelegate')
 	def speechSynthesizer_willSpeakRangeOfSpeech_utterance_(self, *args):
 		print('willSpeakRangeOfSpeech_(): args=', args)
-	"""
 
